# PyRoll Shida Flow Stress Model

Plugin for PyRolL providing the constitutive flow stress function from S. Shida.

For the docs, see [here](docs/index.md).

This project is licensed under the [BSD-3-Clause license](LICENSE).

The package is available via PyPi and can be installed with

    pip install pyroll-shida-flow-stress